@@ -259,7 +259,7 @@ class Interface(object):
                          'config', 'customdata', 'customparams', 'notices',
                          'getIsyInfo', 'getAll', 'setLogLevel',
                          'customtypeddata', 'customtypedparams', 'getNsInfo',
-                         'discover']
+                         'discover', 'nsdata']
 
             parsed_msg = json.loads(msg.payload.decode('utf-8'))
             #LOGGER.debug('MQTT Received Message: {}: {}'.format(msg.topic, parsed_msg))
@@ -310,6 +310,8 @@ class Interface(object):
                     LOGGER.error('error {}'.format(parsed_msg[key]))
                 elif key == 'customparamsdoc':
                     LOGGER.info('customparamsdoc response')
+                elif key == 'setLogLevelList':
+                    LOGGER.info('setLogList response {}'.format(parsed_msg[key]))
                 else:
                     LOGGER.error(
                         'Invalid command received in message from PG3: \'{}\' {}'.format(key, parsed_msg[key]))
@@ -515,7 +517,7 @@ class Interface(object):
                     n.private = node['private']
 
         if 'logLevelList' in config:
-            self._levelsList = config['logLevelList']
+            self._levelsList = json.loads(config['logLevelList'])
 
         if 'logLevel' in config:
             self.currentLogLevel = config['logLevel'].upper()
@@ -601,6 +603,14 @@ class Interface(object):
                 value = item.get('value')
 
             pub.publish(self.CUSTOMPARAMS, None, value)
+        elif key == 'nsdata':
+            #LOGGER.debug('nsdata: {}'.format(item))
+            try:
+                value = json.loads(item)
+            except ValueError as e:
+                value = item
+
+            pub.publish(self.CUSTOMNS, None, key, value)
         elif key == 'customtypedparams':
             try:
                 value = json.loads(item)
@@ -635,7 +645,10 @@ class Interface(object):
                 if item.get('key') == 'customparamsdoc':
                     pub.publish(self.CUSTOMPARAMSDOC, None, item.get('value'))
                 else:
-                    value = json.loads(item.get('value'))
+                    try:
+                        value = json.loads(item.get('value'))
+                    except:
+                        value = item.get('value')
 
                     #LOGGER.error('GETALL -> {} {}'.format(item.get('key'), value))
                     if item.get('key') == 'notices':
@@ -1033,10 +1046,13 @@ class Interface(object):
         for l in self._levelsList:
             if l['id'] > lid:
                 lid = int(l['id'])
+            if l['value'] == name:
+                LOGGER.warn('Attempt to add log level that already exists: {}'.format(name))
+                return
 
         # Add new level to list
         self._levelsList.append( {
-            'id': lid,
+            'id': lid+1,
             'name': str_name,
             'value': name,
             'level': lvl
